@@ -1,3 +1,6 @@
 package My::SchemaBaseClass;
+use strict;
+use warnings;
+
 use base 'DBIx::Class::Schema';
 1;
