@@ -1,4 +1,6 @@
 package TestSchemaComponentFQN;
+use strict;
+use warnings;
 
 sub testschemacomponent_fqn { 'TestSchemaComponentFQN works' }
 
